@@ -1,6 +1,6 @@
 package Ubic::Multiservice::Dir;
 BEGIN {
-  $Ubic::Multiservice::Dir::VERSION = '1.35';
+  $Ubic::Multiservice::Dir::VERSION = '1.36';
 }
 
 use strict;
@@ -13,66 +13,31 @@ use Params::Validate qw(:all);
 use Carp;
 use File::Basename;
 use Scalar::Util qw(blessed);
+use Ubic::ServiceLoader;
 
-sub new($$) {
+sub new {
     my $class = shift;
     my ($dir) = validate_pos(@_, 1);
     return bless { service_dir => $dir } => $class;
 }
 
-sub has_simple_service($$) {
+sub has_simple_service {
     my $self = shift;
     my ($name) = validate_pos(@_, {type => SCALAR, regex => qr/^[\w.-]+$/});
-    return(-e "$self->{service_dir}/$name");
-}
-
-my $eval_id = 1;
-sub simple_service($$) {
-    my $self = shift;
-    my ($name) = validate_pos(@_, {type => SCALAR, regex => qr/^[\w.-]+$/});
-
-    my $file = "$self->{service_dir}/$name";
-    if (-d $file) {
-        # directory => multiservice
-        my $service = Ubic::Multiservice::Dir->new($file);
-        $service->name($name);
-        return $service;
-    }
-    elsif (-e $file) {
-        open my $fh, '<', $file or die "Can't open $file: $!";
-        my $content = do { local $/; <$fh> };
-        close $fh or die "Can't close $file: $!";
-
-        $content = "# line 1 $file\n$content";
-        $content = "package UbicService".($eval_id++).";\n# line 1 $file\n$content";
-        my $service = eval $content;
-        if ($@) {
-            die "Failed to eval '$file': $@";
-        }
-        unless (blessed $service) {
-            die "$file doesn't contain any service";
-        }
-        unless ($service->isa('Ubic::Service')) {
-            die "$file returned $service instead of Ubic::Service";
-        }
-        unless (defined $service->name) {
-            $service->name($name);
-        }
-        return $service;
+    if ($self->_name2file($name)) {
+        return 1;
     }
     else {
-        croak "Service '$name' not found";
+        return;
     }
 }
 
-sub service_names($) {
+sub _filter_files {
     my $self = shift;
+    my @files = @_;
 
-    my @names;
-    for my $file (glob("$self->{service_dir}/*")) {
-        next unless -f $file or -d $file;
-        my $name = basename($file);
-
+    my @filtered;
+    for my $name (@files) {
         # list of taboo extensions is stolen from logrotate(8)
         if ($name =~ /(
                 \.rpmorig   |
@@ -91,21 +56,79 @@ sub service_names($) {
         ) {
             next; # skip silently
         }
+        push @filtered, $name;
+    }
+    return @filtered;
+}
 
-        if ($name !~ /^[\w-]+$/) {
+sub _name2file {
+    my $self = shift;
+    my ($name) = @_;
+
+    my $base = "$self->{service_dir}/$name";
+    my @files = glob "$base.*";
+    unshift @files, $base if -e $base;
+
+    @files = $self->_filter_files(@files);
+
+    unless (@files) {
+        return;
+    }
+
+    if (@files > 1) {
+        for my $file (@files[1 .. $#files]) {
+            warn "Ignoring duplicate service config '$file', using '$files[0]' instead";
+        }
+    }
+    return shift @files;
+}
+
+sub simple_service {
+    my $self = shift;
+    my ($name) = validate_pos(@_, {type => SCALAR, regex => qr/^[\w.-]+$/});
+
+    my $file = $self->_name2file($name);
+    unless (defined $file) {
+        croak "Service '$name' not found";
+    }
+
+    if (-d $file) {
+        # directory => multiservice
+        my $service = Ubic::Multiservice::Dir->new($file);
+        $service->name($name);
+        return $service;
+    }
+
+    my $service = Ubic::ServiceLoader->load($file);
+    $service->name($name);
+    return $service;
+}
+
+sub service_names {
+    my $self = shift;
+
+    my %names;
+
+    my @files = glob("$self->{service_dir}/*");
+    @files = $self->_filter_files(@files);
+    for my $file (@files) {
+        next unless -f $file or -d $file;
+        my $name = basename($file);
+
+        my ($service_name, $ext) = Ubic::ServiceLoader->split_service_filename($name);
+        unless (defined $service_name) {
             warn "Invalid file $file - only alphanumerics, underscores and hyphens are allowed\n";
             next;
         }
 
-        push @names, $name;
+        $names{ $service_name }++;
     }
-    return @names;
+    return sort keys %names;
 }
 
 
 1;
 
-
 __END__
 =pod
 
@@ -115,7 +138,7 @@ Ubic::Multiservice::Dir - multiservice which uses directory with configs to inst
 
 =head1 VERSION
 
-version 1.35
+version 1.36
 
 =head1 METHODS
 
