@@ -1,6 +1,6 @@
 package Ubic::ServiceLoader;
-{
-  $Ubic::ServiceLoader::VERSION = '1.57_01';
+BEGIN {
+  $Ubic::ServiceLoader::VERSION = '1.36';
 }
 
 # ABSTRACT: load service from file
@@ -20,10 +20,9 @@ sub ext2loader {
     my ($ext) = validate_pos(@_, { type => SCALAR, regex => qr/^\w+$/ });
 
     return $ext2loader{$ext} if $ext2loader{$ext};
-    require "Ubic/ServiceLoader/Ext/$ext.pm"; # TODO - improve error message if ext.pm doesn't exist
+    require "Ubic/ServiceLoader/Ext/$ext.pm";
     my $loader_class = "Ubic::ServiceLoader::Ext::$ext";
     return $loader_class->new;
-    # FIXME - cache loader_class!
 }
 
 sub split_service_filename {
@@ -61,18 +60,15 @@ sub load {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Ubic::ServiceLoader - load service from file
 
 =head1 VERSION
 
-version 1.57_01
+version 1.36
 
 =head1 SYNOPSIS
 
@@ -121,9 +117,10 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yandex LLC.
+This software is copyright (c) 2011 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
